-- Example Application Premake File
-- (c) Cesys GmbH, Thomas Hoppe
if (_ACTION == "gmake") then
	loc = "build_" .. os.get()
else
	loc = "build_" .. _ACTION
end	

if (os.get() == "windows") then
	if (_ACTION == "gmake") then
		-- MINGW
		lext = ""
	else
		-- MSVC
		lext = ".lib"
	end
else 
	if (os.get() == "linux") then
		-- LINUX
		lext = ".so"
		
		-- Raspberry Pi
		if string.startswith(os.outputof("uname -m"), "arm") then
			suffix = "-arm"
			loc = "build_linux_arm"
		end		
	else
		-- MACOSX
		lext = ".dylib"
	end
end

solution "CeboMsrExamples"
  platforms { "x32", "x64" }
  configurations { "Debug", "Release" }
  kind "ConsoleApp"
  language "C++"
  
  files { "api/cebomsrpp.cpp", "include/*.h" }
  includedirs { "include/" }
  debugdir "../runtime/"
  
  location (loc)

  configuration "vs*"
	libdirs { "lib/" }
  configuration "not vs*"
	libdirs { "../runtime/" }

  configuration "x32"
    if (suffix == "-arm") then
		targetsuffix ( "-" .. os.get() .. "-arm" )
		links { "cebomsr-1.3-arm.so" }
	else
		targetsuffix ( "-" .. os.get() .. "-x86" )
		links { "cebomsr-1.3-x86" .. lext }
	end
  configuration "x64"
	targetsuffix ( "-" .. os.get() .. "-x64" )
	links { "cebomsr-1.3-x64" .. lext }
	
  configuration "Debug"
	defines { "DEBUG" } 
	flags { "Symbols" }	
	targetdir "bin/debug"
  configuration "Release" 
	defines { "NDEBUG" } 
	flags { "Optimize" }  
	targetdir "bin/release"
	
  project "Counter"		files { "examples/counter.cpp" }      location (loc)
  project "FrameIo"		files { "examples/frameio.cpp" }      location (loc)
  project "Info"		files { "examples/info.cpp" }         location (loc)
  project "SingleIo"	files { "examples/singleio.cpp" }     location (loc)
  project "StreamingI"	files { "examples/streamingi.cpp" }   location (loc)
  project "Trigger"		files { "examples/trigger.cpp" }      location (loc)
