﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Offers functionality for current sources. Instances can be retrieved from
    /// CurrentSources of the respective Device instance.
    /// </summary>
    public sealed class CurrentSource
    {
        private Device _device;
        private uint _interfaceId;
        private int _index;
        private string _name;

        internal uint InterfaceId { get { return _interfaceId; } }
        internal int Index { get { return _index; } }

        internal CurrentSource(Device device, uint interfaceId, int index)
        {
            _device = device;
            _interfaceId = interfaceId;
            _index = index;
            _name = SystemConnector.GetPeripheralName(device.Handle, interfaceId);
        }

        /// <summary>
        /// The real current of the constant current source in micro ampere.
        /// </summary>
        public float ReferenceCurrent { get { return SystemConnector.GetReferenceCurrent(_device.Handle, _interfaceId); } }

        /// <summary>
        /// Name of the component.
        /// </summary>
        public string Name { get { return _name; } }

        public override string ToString()
        {
            return "CurrentSource: " + _name;
        }
    }
}
