﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Class that is responsible for all device independent functionality.
    /// </summary>
    public sealed class LibraryInterface
    {
        /// <summary>
        /// Version of the CeboMsr-Base-API.
        /// </summary>
        public static string ApiVersion { get { return SystemConnector.GetApiVersion(); } }

        /// <summary>
        /// Version of the underlying Cesys USB Base API Layer.
        /// </summary>
        public static string UsbBaseVersion { get { return SystemConnector.GetUsbBaseVersion(); } }

        /// <summary>
        /// Enumerate devices on this system. Already opened devices are not included.
        /// </summary>
        /// <param name="type">Type of devices to enumerate.</param>
        /// <returns>Device ready to use.</returns>
        public static IList<Device> Enumerate(DeviceType type)
        {
            List<Device> r = new List<Device>();

            for (int i = 0; i < SystemConnector.BeginEnumerate(type.InterfaceId); ++i)
            {
                uint msrType = 0;
                string version = "";
                string ident = SystemConnector.GetIdentifier(i, ref msrType, ref version);

                r.Add(new Device(ident, DeviceType.GetDeviceTypeById(msrType), version));
            }

            return r.AsReadOnly();
        }

        /// <summary>
        /// *** unofficial experimental feature, don't use ***
        /// </summary>
        public static IList<Device> EnumerateNetwork(string hostname, int port, DeviceType type)
        {
            List<Device> r = new List<Device>();

            for (int i = 0; i < SystemConnector.BeginEnumerateNetwork(hostname, port, type.InterfaceId); ++i)
            {
                uint msrType = 0;
                string version = "";
                string ident = SystemConnector.GetIdentifier(i, ref msrType, ref version);

                r.Add(new Device(ident, DeviceType.GetDeviceTypeById(msrType), version));
            }

            return r.AsReadOnly();
        }
    }
}
