﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Offers functionality for triggers. Instances can be retrieved from Triggers
    /// of the respective Device instance.
    /// </summary>
    public sealed class Trigger : IInput
    {
        /// <summary>
        /// The possible trigger configuration values.
        /// </summary>
        public enum TriggerConfig : uint
        {
            OutputPulse = SystemConnector.CeboMsrTriggerOutputPulse,
            OutputAlternating = SystemConnector.CeboMsrTriggerOutputAlternating,
            InputRisingEdge = SystemConnector.CeboMsrTriggerInputRisingEdge,
            InputFallingEdge = SystemConnector.CeboMsrTriggerInputFallingEdge,
            InputAlternating = SystemConnector.CeboMsrTriggerInputAlternating
        }

        private Device _device;
        private uint _interfaceId;
        private int _index;
        private string _name;

        internal uint InterfaceId { get { return _interfaceId; } }
        internal int Index { get { return _index; } }

        internal Trigger(Device device, uint interfaceId, int index)
        {
            _device = device;
            _interfaceId = interfaceId;
            _index = index;
            _name = SystemConnector.GetPeripheralName(device.Handle, interfaceId);
        }

        /// <summary>
        /// Define or retrieve the triggers enabled state.
        /// </summary>
        public bool Enabled
        {
            get { return SystemConnector.GetTriggerEnable(_device.Handle, _interfaceId); }
            set { SystemConnector.SetTriggerEnable(_device.Handle, _interfaceId, value); }
        }

        /// <summary>
        /// Define and request behavior of the trigger.
        /// </summary>
        public TriggerConfig Config
        {
            get { return (TriggerConfig)SystemConnector.GetTriggerConfig(_device.Handle, _interfaceId); }
            set { SystemConnector.SetTriggerConfig(_device.Handle, _interfaceId, (uint)value); }
        }

        /// <summary>
        /// Name of the component.
        /// </summary>
        public string Name { get { return _name; } }

        public override string ToString()
        {
            return "Trigger" + _index;
        }
    }
}
